@@ -4,7 +4,7 @@ log = logging.getLogger(__name__)
 
 from supervised.validation.validator_kfold import KFoldValidator
 from supervised.validation.validator_split import SplitValidator
-from supervised.validation.validator_with_dataset import WithDatasetValidator
+from supervised.validation.validator_custom import CustomValidator
 
 from supervised.exceptions import AutoMLException
 
@@ -19,18 +19,12 @@ class ValidationStep:
             self.validator = KFoldValidator(params)
         elif self.validation_type == "split":
             self.validator = SplitValidator(params)
+        elif self.validation_type == "custom":
+            self.validator = CustomValidator(params)
         else:
             raise AutoMLException(
                 f"The validation type ({self.validation_type}) is not implemented."
             )
-        """
-        
-        elif self.validation_type == "with_dataset":
-            self.validator = WithDatasetValidator(params, data)
-        else:
-            msg = "Unknown validation type: {0}".format(self.validation_type)
-            raise ValidationStepException(msg)
-        """
 
     def get_split(self, k, repeat=0):
         return self.validator.get_split(k, repeat)
